FieldElement51

Struct FieldElement51 

pub struct FieldElement51(/* private fields */);
Available on curve25519_dalek_bits=64 and docsrs only.
A FieldElement51 represents an element of the field \( \mathbb Z / (2^{255} - 19)\).

In the 64-bit implementation, a FieldElement is represented in radix \(2^{51}\) as five u64s; the coefficients are allowed to grow up to \(2^{54}\) between reductions modulo \(p\).

Note

The curve25519_dalek::field module provides a type alias curve25519_dalek::field::FieldElement to either FieldElement51 or FieldElement2625.

The backend-specific type FieldElement51 should not be used outside of the curve25519_dalek::field module.

Implementations

Source

impl FieldElement51

pub const ZERO: FieldElement51

The scalar \( 0 \).

pub const ONE: FieldElement51

The scalar \( 1 \).

pub const MINUS_ONE: FieldElement51

The scalar \( -1 \).

pub fn negate(&mut self)

Invert the sign of this field element

pub fn from_bytes(bytes: &[u8; 32]) -> FieldElement51

Load a FieldElement51 from the low 255 bits of a 256-bit input.

Warning

This function does not check that the input used the canonical representative. It masks the high bit, but it will happily decode 2^255 - 18 to 1. Applications that require a canonical encoding of every field element should decode, re-encode to the canonical encoding, and check that the input was canonical.

pub fn as_bytes(&self) -> [u8; 32]

Serialize this FieldElement51 to a 32-byte array. The encoding is canonical.

pub fn pow2k(&self, k: u32) -> FieldElement51

Given k > 0, return self^(2^k).

pub fn square(&self) -> FieldElement51

Returns the square of this field element.

pub fn square2(&self) -> FieldElement51

Returns 2 times the square of this field element.